==> sems-0.8.12.tar.gz: sems-0.8.12/sems.h <==
/*
 * $Id: sems.h,v 1.1.2.4 2004/10/20 14:29:48 paka Exp $
 *
 * Copyright (C) 2002-2003 Fhg Fokus
 *
 * This file is part of sems, a free SIP media server.
 *
 * sems is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version
 *
 * For a license to use the ser software under conditions
 * other than those described here, or to purchase support for this
 * software, please contact iptel.org by e-mail at the following addresses:
 *    info@iptel.org
 *
 * sems is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef _ans_machine_h_
#define _ans_machine_h_

#ifndef CONFIG_FILE
#define CONFIG_FILE         "/usr/local/etc/sems/sems.conf"
#endif

#define SER_FIFO            "/tmp/ser_fifo"
#define FIFO_NAME           "/tmp/am_fifo"
#define ANNOUNCE_PATH       "/usr/local/lib/sems/audio"
#define ANNOUNCE_FILE       "default.wav"
#define PLUG_IN_PATH        "/usr/local/lib/sems/plug-in"
#define DEFAULT_ANNOUNCE    "default.wav"
#define SMTP_ADDRESS_IP     "localhost"
#define SMTP_PORT           25
#define DEFAULT_RECORD_TIME 30
#define DEFAULT_DAEMON_MODE 1
#define PREFIX_SEPARATOR    '\0'
#define RTP_LOWPORT         1024
#define RTP_HIGHPORT        0xffff

#define MAX_NET_DEVICES     32

extern const char* progname;

#include "AmAudio.h"

#endif

==> sems-0.9.0.tar.gz: sems-0.9.0/sems.h <==
/*
 * $Id: sems.h,v 1.4 2005/02/27 21:59:40 sobomax Exp $
 *
 * Copyright (C) 2002-2003 Fhg Fokus
 *
 * This file is part of sems, a free SIP media server.
 *
 * sems is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version
 *
 * For a license to use the ser software under conditions
 * other than those described here, or to purchase support for this
 * software, please contact iptel.org by e-mail at the following addresses:
 *    info@iptel.org
 *
 * sems is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef _ans_machine_h_
#define _ans_machine_h_

#define CONFIG_FILE         PREFIX "/etc/sems/sems.conf"
#define SER_FIFO            "/tmp/ser_fifo"
#define FIFO_NAME           "/tmp/am_fifo"
#define SEND_METHOD         "fifo"
#define ANNOUNCE_PATH       PREFIX "/lib/sems/audio"
#define ANNOUNCE_FILE       "default.wav"
#define PLUG_IN_PATH        PREFIX "/lib/sems/plug-in"
#define DEFAULT_ANNOUNCE    "default.wav"
#define SMTP_ADDRESS_IP     "localhost"
#define SMTP_PORT           25
#define DEFAULT_RECORD_TIME 30
#define DEFAULT_DAEMON_MODE 1
#define PREFIX_SEPARATOR    '\0'
#define RTP_LOWPORT         1024
#define RTP_HIGHPORT        0xffff

#define MAX_NET_DEVICES     32

extern const char* progname;

#include "AmAudio.h"

#endif
